utils

package
v0.0.16 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 20, 2026 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AddKubeconfigArgs added in v0.0.8

func AddKubeconfigArgs(args []string) []string

AddKubeconfigArgs adds kubeconfig arguments to command args if configured

func GetKubeconfig added in v0.0.8

func GetKubeconfig() string

GetKubeconfig returns the global kubeconfig path in a thread-safe manner

func RegisterTools added in v0.0.8

func RegisterTools(s *server.MCPServer, readOnly bool)

func SetKubeconfig added in v0.0.8

func SetKubeconfig(path string)

SetKubeconfig sets the global kubeconfig path in a thread-safe manner

Types

type KubeConfigManager added in v0.0.8

type KubeConfigManager struct {
	// contains filtered or unexported fields
}

KubeConfigManager manages kubeconfig path with thread safety

Jump to